/*
 *      Copyright (c) 2018-2028, Chill Zhuang All rights reserved.
 *
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions are met:
 *
 *  Redistributions of source code must retain the above copyright notice,
 *  this list of conditions and the following disclaimer.
 *  Redistributions in binary form must reproduce the above copyright
 *  notice, this list of conditions and the following disclaimer in the
 *  documentation and/or other materials provided with the distribution.
 *  Neither the name of the dreamlu.net developer nor the names of its
 *  contributors may be used to endorse or promote products derived from
 *  this software without specific prior written permission.
 *  Author: Chill 庄骞 (smallchill@163.com)
 */
package org.springblade.modules.api.request;

import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import lombok.Data;

import javax.validation.constraints.NotBlank;
import javax.validation.constraints.NotEmpty;
import java.io.Serializable;
import java.util.List;

/**
 * 请求实体类
 *
 * @author BladeX
 * @since 2022-02-13
 */
@Data
@ApiModel(value = "新增订单实体对象", description = "请求实体类")
public class OrderCommonSaveRequest implements Serializable {

	private static final long serialVersionUID = 1L;

	/**
	 * 用户ID
	 */
	@ApiModelProperty(value = "用户ID")
	private Long userId;

	@NotBlank(message = "请输入手机号")
	@ApiModelProperty(value = "联系电话")
	private String telPhone;

	@ApiModelProperty(value = "支付价")
	private Double payFee;

	@NotBlank(message = "请输入收货地址")
	@ApiModelProperty(value = "收货地址")
	private String userAddress;

	@ApiModelProperty(value = "配送方式，1物流配送，2到店自取")
	private Integer distributeMode;

	@ApiModelProperty(value = "运费")
	private Double wlPrice;

	@ApiModelProperty(value = "配送信息")
	private String deliveryStaff;


	@NotBlank(message = "请输入收货人")
	@ApiModelProperty(value = "收货人")
	private String receivingName;

	@ApiModelProperty(value = "商品信息")
	private List<OrderGoodsSaveRequest> goodsList;


}
