/*
 *      Copyright (c) 2018-2028, Chill Zhuang All rights reserved.
 *
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions are met:
 *
 *  Redistributions of source code must retain the above copyright notice,
 *  this list of conditions and the following disclaimer.
 *  Redistributions in binary form must reproduce the above copyright
 *  notice, this list of conditions and the following disclaimer in the
 *  documentation and/or other materials provided with the distribution.
 *  Neither the name of the dreamlu.net developer nor the names of its
 *  contributors may be used to endorse or promote products derived from
 *  this software without specific prior written permission.
 *  Author: Chill 庄骞 (smallchill@163.com)
 */
package org.springblade.modules.finance.controller;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import com.github.xiaoymin.knife4j.annotations.ApiOperationSupport;
import lombok.AllArgsConstructor;
import javax.validation.Valid;

import org.springblade.core.mp.support.Condition;
import org.springblade.core.mp.support.Query;
import org.springblade.core.tool.api.R;
import org.springblade.core.tool.utils.Func;
import org.springblade.modules.finance.wrapper.OrderConsignWrapper;
import org.springframework.web.bind.annotation.*;
import com.baomidou.mybatisplus.core.metadata.IPage;
import org.springblade.modules.finance.entity.OrderConsign;
import org.springblade.modules.finance.vo.OrderConsignVO;
import org.springblade.modules.finance.service.IOrderConsignService;
import org.springblade.core.boot.ctrl.BladeController;

/**
 * 寄售订单表 控制器
 *
 * @author BladeX
 * @since 2022-02-13
 */
@RestController
@AllArgsConstructor
@RequestMapping("finance/orderconsign")
@Api(value = "寄售订单表", tags = "寄售订单表接口")
public class OrderConsignController extends BladeController {

	private final IOrderConsignService orderConsignService;

	/**
	 * 详情
	 */
	@GetMapping("/detail")
	@ApiOperationSupport(order = 1)
	@ApiOperation(value = "详情", notes = "传入orderConsign")
	public R<OrderConsign> detail(OrderConsign orderConsign) {
		OrderConsign detail = orderConsignService.getOne(Condition.getQueryWrapper(orderConsign));
		return R.data(detail);
	}

	/**
	 * 分页 寄售订单表
	 */
	@GetMapping("/list")
	@ApiOperationSupport(order = 2)
	@ApiOperation(value = "分页", notes = "传入orderConsign")
	public R<IPage<OrderConsignVO>> list(OrderConsign orderConsign, Query query) {
		IPage<OrderConsign> pages = orderConsignService.page(Condition.getPage(query),
			Condition.getQueryWrapper(orderConsign).orderByDesc("create_time"));
		return R.data(OrderConsignWrapper.build().pageVO(pages));
	}

	/**
	 * 自定义分页 寄售订单表
	 */
	@GetMapping("/page")
	@ApiOperationSupport(order = 3)
	@ApiOperation(value = "分页", notes = "传入orderConsign")
	public R<IPage<OrderConsignVO>> page(OrderConsignVO orderConsign, Query query) {
		IPage<OrderConsignVO> pages = orderConsignService.selectOrderConsignPage(Condition.getPage(query), orderConsign);
		return R.data(pages);
	}

	/**
	 * 新增 寄售订单表
	 */
	@PostMapping("/save")
	@ApiOperationSupport(order = 4)
	@ApiOperation(value = "新增", notes = "传入orderConsign")
	public R save(@Valid @RequestBody OrderConsign orderConsign) {
		return R.status(orderConsignService.save(orderConsign));
	}

	/**
	 * 修改 寄售订单表
	 */
	@PostMapping("/update")
	@ApiOperationSupport(order = 5)
	@ApiOperation(value = "修改", notes = "传入orderConsign")
	public R update(@Valid @RequestBody OrderConsign orderConsign) {
		return R.status(orderConsignService.updateById(orderConsign));
	}

	/**
	 * 新增或修改 寄售订单表
	 */
	@PostMapping("/submit")
	@ApiOperationSupport(order = 6)
	@ApiOperation(value = "新增或修改", notes = "传入orderConsign")
	public R submit(@Valid @RequestBody OrderConsign orderConsign) {
		return R.status(orderConsignService.saveOrUpdate(orderConsign));
	}


	/**
	 * 删除 寄售订单表
	 */
	@PostMapping("/remove")
	@ApiOperationSupport(order = 8)
	@ApiOperation(value = "删除", notes = "传入ids")
	public R remove(@ApiParam(value = "主键集合", required = true) @RequestParam String ids) {
		return R.status(orderConsignService.removeByIds(Func.toLongList(ids)));
	}


}
