/*
 *      Copyright (c) 2018-2028, Chill Zhuang All rights reserved.
 *
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions are met:
 *
 *  Redistributions of source code must retain the above copyright notice,
 *  this list of conditions and the following disclaimer.
 *  Redistributions in binary form must reproduce the above copyright
 *  notice, this list of conditions and the following disclaimer in the
 *  documentation and/or other materials provided with the distribution.
 *  Neither the name of the dreamlu.net developer nor the names of its
 *  contributors may be used to endorse or promote products derived from
 *  this software without specific prior written permission.
 *  Author: Chill 庄骞 (smallchill@163.com)
 */
package org.springblade.modules.finance.wrapper;

import cn.hutool.core.util.ObjectUtil;
import org.springblade.common.cache.DictBizCache;
import org.springblade.common.enums.DictBizEnum;
import org.springblade.core.mp.support.BaseEntityWrapper;
import org.springblade.core.tool.utils.BeanUtil;
import org.springblade.core.tool.utils.SpringUtil;
import org.springblade.modules.finance.entity.OrderGrant;
import org.springblade.modules.finance.entity.PlatformAuthorization;
import org.springblade.modules.finance.service.IOrderGrantService;
import org.springblade.modules.finance.vo.OrderGrantVO;
import org.springblade.modules.finance.vo.PlatformAuthorizationVO;
import org.springblade.modules.system.entity.User;
import org.springblade.modules.system.service.IUserService;

import java.util.Objects;

/**
 * 包装类,返回视图层所需的字段
 *
 * @author Chill
 */
public class PlatformAuthorizationWrapper extends BaseEntityWrapper<PlatformAuthorization, PlatformAuthorizationVO> {

	public static PlatformAuthorizationWrapper build() {
		return new PlatformAuthorizationWrapper();
	}

	public static IUserService userService;

	static {
		userService = SpringUtil.getBean(IUserService.class);
	}

	@Override
	public PlatformAuthorizationVO entityVO(PlatformAuthorization entity) {
		PlatformAuthorizationVO vo = Objects.requireNonNull(BeanUtil.copy(entity, PlatformAuthorizationVO.class));
		User user = userService.getById(vo.getCreateUserId());
		if (ObjectUtil.isNotNull(user)){
			vo.setAccount(user.getAccount());
			vo.setRealName(user.getRealName());
		}
		vo.setStateDisplayName(DictBizCache.getValue(DictBizEnum.AUTH_STATE,vo.getState()));
		return vo;
	}

}
