/*
 *      Copyright (c) 2018-2028, Chill Zhuang All rights reserved.
 *
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions are met:
 *
 *  Redistributions of source code must retain the above copyright notice,
 *  this list of conditions and the following disclaimer.
 *  Redistributions in binary form must reproduce the above copyright
 *  notice, this list of conditions and the following disclaimer in the
 *  documentation and/or other materials provided with the distribution.
 *  Neither the name of the dreamlu.net developer nor the names of its
 *  contributors may be used to endorse or promote products derived from
 *  this software without specific prior written permission.
 *  Author: Chill 庄骞 (smallchill@163.com)
 */
package org.springblade.modules.shopping.controller;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import com.github.xiaoymin.knife4j.annotations.ApiOperationSupport;
import lombok.AllArgsConstructor;
import javax.validation.Valid;

import org.springblade.core.mp.support.Condition;
import org.springblade.core.mp.support.Query;
import org.springblade.core.tool.api.R;
import org.springblade.core.tool.utils.Func;
import org.springframework.web.bind.annotation.*;
import com.baomidou.mybatisplus.core.metadata.IPage;
import org.springblade.modules.shopping.entity.Attributes;
import org.springblade.modules.shopping.vo.AttributesVO;
import org.springblade.modules.shopping.service.IAttributesService;
import org.springblade.core.boot.ctrl.BladeController;

/**
 * 属性表 控制器
 *
 * @author BladeX
 * @since 2022-02-13
 */
@RestController
@AllArgsConstructor
@RequestMapping("shopping/attributes")
@Api(value = "属性表", tags = "属性表接口")
public class AttributesController extends BladeController {

	private final IAttributesService attributesService;

	/**
	 * 详情
	 */
	@GetMapping("/detail")
	@ApiOperationSupport(order = 1)
	@ApiOperation(value = "详情", notes = "传入attributes")
	public R<Attributes> detail(Attributes attributes) {
		Attributes detail = attributesService.getOne(Condition.getQueryWrapper(attributes));
		return R.data(detail);
	}

	/**
	 * 分页 属性表
	 */
	@GetMapping("/list")
	@ApiOperationSupport(order = 2)
	@ApiOperation(value = "分页", notes = "传入attributes")
	public R<IPage<Attributes>> list(Attributes attributes, Query query) {
		IPage<Attributes> pages = attributesService.page(Condition.getPage(query), Condition.getQueryWrapper(attributes));
		return R.data(pages);
	}

	/**
	 * 自定义分页 属性表
	 */
	@GetMapping("/page")
	@ApiOperationSupport(order = 3)
	@ApiOperation(value = "分页", notes = "传入attributes")
	public R<IPage<AttributesVO>> page(AttributesVO attributes, Query query) {
		IPage<AttributesVO> pages = attributesService.selectAttributesPage(Condition.getPage(query), attributes);
		return R.data(pages);
	}

	/**
	 * 新增 属性表
	 */
	@PostMapping("/save")
	@ApiOperationSupport(order = 4)
	@ApiOperation(value = "新增", notes = "传入attributes")
	public R save(@Valid @RequestBody Attributes attributes) {
		return R.status(attributesService.save(attributes));
	}

	/**
	 * 修改 属性表
	 */
	@PostMapping("/update")
	@ApiOperationSupport(order = 5)
	@ApiOperation(value = "修改", notes = "传入attributes")
	public R update(@Valid @RequestBody Attributes attributes) {
		return R.status(attributesService.updateById(attributes));
	}

	/**
	 * 新增或修改 属性表
	 */
	@PostMapping("/submit")
	@ApiOperationSupport(order = 6)
	@ApiOperation(value = "新增或修改", notes = "传入attributes")
	public R submit(@Valid @RequestBody Attributes attributes) {
		return R.status(attributesService.saveOrUpdate(attributes));
	}

	
	/**
	 * 删除 属性表
	 */
	@PostMapping("/remove")
	@ApiOperationSupport(order = 8)
	@ApiOperation(value = "删除", notes = "传入ids")
	public R remove(@ApiParam(value = "主键集合", required = true) @RequestParam String ids) {
		return R.status(attributesService.removeByIds(Func.toLongList(ids)));
	}

	
}
