/*
 *      Copyright (c) 2018-2028, Chill Zhuang All rights reserved.
 *
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions are met:
 *
 *  Redistributions of source code must retain the above copyright notice,
 *  this list of conditions and the following disclaimer.
 *  Redistributions in binary form must reproduce the above copyright
 *  notice, this list of conditions and the following disclaimer in the
 *  documentation and/or other materials provided with the distribution.
 *  Neither the name of the dreamlu.net developer nor the names of its
 *  contributors may be used to endorse or promote products derived from
 *  this software without specific prior written permission.
 *  Author: Chill 庄骞 (smallchill@163.com)
 */
package org.springblade.modules.shopping.controller;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import com.github.xiaoymin.knife4j.annotations.ApiOperationSupport;
import lombok.AllArgsConstructor;
import javax.validation.Valid;

import org.springblade.core.mp.support.Condition;
import org.springblade.core.mp.support.Query;
import org.springblade.core.tool.api.R;
import org.springblade.core.tool.utils.Func;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.bind.annotation.RequestParam;
import com.baomidou.mybatisplus.core.metadata.IPage;
import org.springblade.modules.shopping.entity.ConsignRule;
import org.springblade.modules.shopping.vo.ConsignRuleVO;
import org.springblade.modules.shopping.wrapper.ConsignRuleWrapper;
import org.springblade.modules.shopping.service.IConsignRuleService;
import org.springblade.core.boot.ctrl.BladeController;

/**
 * 规则条件表 控制器
 *
 * @author BladeX
 * @since 2022-03-15
 */
@RestController
@AllArgsConstructor
@RequestMapping("shopping/consignrule")
@Api(value = "规则条件表", tags = "规则条件表接口")
public class ConsignRuleController extends BladeController {

	private final IConsignRuleService consignRuleService;

	/**
	 * 详情
	 */
	@GetMapping("/detail")
	@ApiOperationSupport(order = 1)
	@ApiOperation(value = "详情", notes = "传入consignRule")
	public R<ConsignRuleVO> detail(ConsignRule consignRule) {
		ConsignRule detail = consignRuleService.getOne(Condition.getQueryWrapper(consignRule));
		return R.data(ConsignRuleWrapper.build().entityVO(detail));
	}

	/**
	 * 分页 规则条件表
	 */
	@GetMapping("/list")
	@ApiOperationSupport(order = 2)
	@ApiOperation(value = "分页", notes = "传入consignRule")
	public R<IPage<ConsignRuleVO>> list(ConsignRule consignRule, Query query) {
		IPage<ConsignRule> pages = consignRuleService.page(Condition.getPage(query), Condition.getQueryWrapper(consignRule));
		return R.data(ConsignRuleWrapper.build().pageVO(pages));
	}


	/**
	 * 自定义分页 规则条件表
	 */
	@GetMapping("/page")
	@ApiOperationSupport(order = 3)
	@ApiOperation(value = "分页", notes = "传入consignRule")
	public R<IPage<ConsignRuleVO>> page(ConsignRuleVO consignRule, Query query) {
		IPage<ConsignRuleVO> pages = consignRuleService.selectConsignRulePage(Condition.getPage(query), consignRule);
		return R.data(pages);
	}

	/**
	 * 新增 规则条件表
	 */
	@PostMapping("/save")
	@ApiOperationSupport(order = 4)
	@ApiOperation(value = "新增", notes = "传入consignRule")
	public R save(@Valid @RequestBody ConsignRule consignRule) {
		return R.status(consignRuleService.save(consignRule));
	}

	/**
	 * 修改 规则条件表
	 */
	@PostMapping("/update")
	@ApiOperationSupport(order = 5)
	@ApiOperation(value = "修改", notes = "传入consignRule")
	public R update(@Valid @RequestBody ConsignRule consignRule) {
		return R.status(consignRuleService.updateById(consignRule));
	}

	/**
	 * 新增或修改 规则条件表
	 */
	@PostMapping("/submit")
	@ApiOperationSupport(order = 6)
	@ApiOperation(value = "新增或修改", notes = "传入consignRule")
	public R submit(@Valid @RequestBody ConsignRule consignRule) {
		return R.status(consignRuleService.saveOrUpdate(consignRule));
	}

	
	/**
	 * 删除 规则条件表
	 */
	@PostMapping("/remove")
	@ApiOperationSupport(order = 7)
	@ApiOperation(value = "逻辑删除", notes = "传入ids")
	public R remove(@ApiParam(value = "主键集合", required = true) @RequestParam String ids) {
		return R.status(consignRuleService.deleteLogic(Func.toLongList(ids)));
	}

	
}
